package Security::irix;

use Exporter;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT = qw( &init() &check() );

sub init {
	$main::showmount = '/usr/bin/showmount';
	$main::kerneldir='/System/Library/Extensions';
	$main::securefile='/etc/ttys';
	$main::sudofile = '/etc/sudoers';
}

sub check {
	&Security::rootlogin::check_defaultlogin() 
		if ( defined &Security::rootlogin::check_defaultlogin );
}

sub run_showfiles {
	print ( STDERR "In run_showfiles\n") if ( $main::opts{'d'} );

	my ($type, $cursum, $sum, $curblock, $bytes, $package, $dummy, $name);
     my ($dev,$ino,$mode,$nlink,$uid,$gid,%checked,$rdev,$curbytes);
	my (%missingfile, %badbytes, %badsum, %badcursum, %badcurbytes, %badtype);
     open (FP, "showfiles -A -M |") || die "Could not run showfiles";
     while (<FP>) {
          ($type, $sum, $bytes, $package, $dummy, $name) =
               split (/[\s\t]+/o, $_);

          $name = $dummy if ( !length ($name));

          # skip the configuration files, they should have changed
          next if ( $dummy eq 'c' );

          if ( ! -e $name ) {
               $missingfile{$name} = 1;
               next;
          }

          ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$curbytes) = lstat($name);

		# need to use /bin/sum -r because that is what showfiles uses.
          if ( $type eq 'f' && $sum )  {
               ($cursum, $curblock, $dummy) =
                    split (/[\s\t]+/o, `/bin/sum -r $name`);

               # Any file definitions from patch packages rule.
               next if ( defined $checked{$name} && $package !~ /patch/o );

               if ( $sum != $cursum ) {
                    $badsum{$name} = $sum;
                    $badcursum{$name} = $cursum;
               } elsif ( defined $badsum{$name} ) {
                    delete $badsum{$name};
                    delete $badsum{$name};
               }

               if ( $bytes != $curbytes ) {
                    $badbytes{$name} = $bytes;
                    $badcurbytes{$name} = $curbytes;
               } elsif ( defined $badbytes{$name} ) {
                    delete $badbytes{$name};
               }
          }

          $badtype{$name} = $mode if ($type eq 'F' && !($mode & 0x1000));
          $badtype{$name} = $mode if ($type eq 'c' && !($mode & 0x2000));
          $badtype{$name} = $mode if ($type eq 'd' && !($mode & 0x4000));
          $badtype{$name} = $mode if ($type eq 'b' && !($mode & 0x6000));
          $badtype{$name} = $mode if ($type eq 'f' && !($mode & 0x8000));
          $badtype{$name} = $mode if ($type eq 'l' && !($mode & 0xA000));
          $badtype{$name} = $mode if ($type eq 's' && !($mode & 0xC000));

          # Now add it to the list of files checked
          $checked{$name} = 1;
     }
     close FP;

	# Now process the info so we can display it correctly
     my ($dir);
     my (@f_keys) = keys %missingfile;
     my (@s_keys) = keys %badsum;
     my (@t_keys) = keys %badtype;
     my (@keys) = (@f_keys, @s_keys, @t_keys);
     foreach $dir (sort @keys) {
		$main::perms{$dir} = "$main::perms{$dir} pathname does not exist" 
			if (defined $missingfile{$dir});

          $main::perms{$dir} = "$main::perms{$dir} size ($badbytes{$dir}:$badcurbytes{$dir})" 
			if (defined $badbytes{$dir});

          $main::perms{$dir} = "$main::perms{$dir} cksum ($badsum{$dir}:$badcursum{$dir})" 
			if (defined $badsum{$dir});

          $main::perms{$dir} = "$main::perms{$dir} pathname not correct type" 
			if (defined $badtype{$dir});

		$main::perms{$dir} =~ s/  / /go;
     }
}

1;
