package Security::mail;

use Security::find;
use Exporter;
use POSIX;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT = qw(&init() &check() &print());

our (%mailowner, %mailgroup, %mailworld);

sub init {
	print ( STDERR  "In Security::mail::init()\n") if ( $main::opts{'d'} );

	&main::read_config('mailfiles');
	&main::read_config('ignoremailfiles');
}

sub check {
	print ( STDERR  "In Security::mail::check()\n") if ( $main::opts{'d'} );

	setpwent;
	while (my($nm, $pw, $uid, $gid, $q, $c, $gcos, $dir) = getpwent) {
		if ( !grep (/^${nm}$/, @main::ignoremailfiles) && $nm ne '+' && -d $dir ) {
			foreach my $file ( @main::mailfiles ) {
				if ( -f $dir . '/' . $file ) {
					my ($dev,$ino,$mode,$nlink,$u,$g,$rdev,$curbytes) = 
						&Security::find::get_stat($dir, 'lstat');

					# If the home dir does not match this account
					# flag it, since we have a file in the 
					# mailfiles list.
					$mailowner{$dir} = 1
						if ( $uid != $u );

					# If the home dir is group or world writeable
					# that means they could have tweaked the 
					# file as well.
					$mailgroup{$dir} = 1
						if ( $mode & &S_IWGRP() );

					$mailworld{$dir} = 1
						if ( $mode & &S_IWOTH() );

					($dev,$ino,$mode,$nlink,$u,$g,$rdev,$curbytes) = 
						&Security::find::get_stat($dir . '/' . $file, 'lstat');

					# If the file itself is not owned by this user,
					# flag this as a problem.
					$mailowner{$dir . '/' . $file} = 1
						if ( $uid != $u );

					# If the file itself is group or world writeable
					# that means some one else could have tweaked the file
					$mailgroup{$dir . '/' . $file} = 1
						if ( $mode & &S_IWGRP() );

					$mailworld{$dir . '/' . $file} = 1
						if ( $mode & &S_IWOTH() );
				}
			}
		}
	}
	endpwent;
}

sub print {
	print ( STDERR  "In Security::mail::print()\n") if ( $main::opts{'d'} );

	&main::print_data ("\n\nchecking for mail files with improper ownership:\n", %mailowner);
	&main::print_data ("\n\nchecking for mail files with group writeable mode:\n", %mailgroup);
	&main::print_data ("\n\nchecking for mail files with world writeable mode:\n", %mailworld);
}

1;
